# frozen_string_literal: true

require 'import'
require 'i18n'
require 'tenant/errors'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/tasks/actionable'

module Tenant
  module Actions

    class Node
      include ::Platform::Tasks::Actionable
      include Import['stores.tenants_directory', 'stores.shards_directory']

      # Example: `Tenant::Actions::Node.call(params: {id: some_id})`
      def call
        crn = context.params[:id]

        node = case crn[:service]
        when "tenant"
          resolve_tenant_node(crn)
        else
          # CoerceInput resolver handles any unknown services with proper error handling
          raise NotImplementedError
        end

        context.node = node
      end

      private

      def resolve_tenant_node(crn)
        tenants_directory.from_customer_id(crn[:customer])
      end
    end

  end
end
