# frozen_string_literal: true

require 'import'
require 'i18n'
require 'tenant/errors'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/tasks/actionable'
require 'tenant/helpers/database'

module Tenant
  module Actions

    class PrivacyNotice
      include ::Platform::Tasks::Actionable
      include Import['logger','stores.shards_directory']
      include ::Tenant::Helpers::Database

      def call
        customer_id = context[:request].current_customer
        privacy_notice = privacy_notice(customer_id)
        context.privacy_notice = privacy_notice
      end

      def privacy_notice(customer_id)
        logger.info("Fetch privacy notice for #{customer_id}")
        # Lookup message on customer shard, default org
        customer_shard = shards_directory.by_customer_id_and_main(customer_id: customer_id)

        logger.info("Customer shard found for #{customer_id} = #{customer_shard.to_json}")

        notice = lookup_notice(customer_shard, customer_id)
        ::Tenant::Models::PrivacyNotice.new(
            message: "#{notice}"
        )
      end

      def lookup_notice(customer_shard, customer_id)
        notice = Multidb.use("db#{customer_shard.activeShardId}") do
          ::Tenant::ArModels::Customer.where(id: customer_id).first&.customer_messages&.to_a[0]&.message
        end
        notice
      end
    end
  end
end