# frozen_string_literal: true

require 'import'
require 'i18n'
require 'tenant/errors'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/tasks/actionable'

module Tenant
  module Actions

    class ShardAssignment
      include ::Platform::Tasks::Actionable
      include Import['stores.shards_directory']

      def call
        customer_id = context[:request].current_customer
        data_store_name = context.params[:input][:data_store_name]

        context.shard_assignment = resolve_shard_assignment(customer_id,
                                                            data_store_name)
      end

      def resolve_shard_assignment(customer_id, data_store_name)
        # Downcase the enum data_store_name to map to our data store names
        shards_directory.by_customer_id_and_store_name(customer_id: customer_id,
                                                       data_store_name: data_store_name.downcase)
      rescue ::Tenant::Stores::ShardsDirectory::InvalidDataStore
        context.fail!(
          error: I18n.t("error_codes.#{::Tenant::ErrorCodes::INVALID_DATA_STORE}")
        )
      rescue ::Tenant::Stores::ShardsDirectory::AssignmentNotFoundError
        context.fail!(
          error: I18n.t("error_codes.#{::Tenant::ErrorCodes::ASSIGNMENT_NOT_FOUND}")
        )
      end
    end

  end
end
