require 'csp-am'
require 'csp-slc'
require 'import'

module Tenant
  module Clients
    class CspApiClient
      include Import['logger', 'settings']

      def am(access_token = nil)
        unless @am
          config = ::CspAm::Configuration.new

          if settings.csp_uri
            uri = settings.csp_uri

            config.scheme = uri.scheme
            config.host = if uri.port == uri.default_port
                                then uri.host
                              else "#{uri.host}:#{uri.port}"
                          end
            config.base_path = uri.path
          end
          config.logger = logger
          config.debugging = false

          @am = ::CspAm::ApiClient.new config
        end

        if ! access_token.nil?
          @am.default_headers['csp-auth-token'] = access_token
        end

        @am
      end

      def slc(access_token = nil)
        unless @slc
          config = ::CspSlc::Configuration.new

          if settings.csp_uri
            uri = settings.csp_uri

            config.scheme = uri.scheme
            config.host = if uri.port == uri.default_port
            then uri.host
                          else "#{uri.host}:#{uri.port}"
                          end
            config.base_path = uri.path
          end
          config.logger = logger
          config.debugging = false

          @slc = ::CspSlc::ApiClient.new config
        end

        if ! access_token.nil?
          @slc.default_headers['csp-auth-token'] = access_token
        end

        @slc
      end
    end
  end
end