require 'import'
require 'base64'
require 'csp-am'
require 'tenant/clients/csp_api_client'
require 'cht-lib-fabric/helpers/wavefront'

module Tenant
  module Clients
    class CspAuthClient
      include Import['logger', 'settings', :wavefront], ::Tenant::Clients
      include ::Platform::Helpers::Wavefront

      DEFAULT_GRANT_TYPE = "client_credentials"

      def fetch_access_token_using_oauth(csp_organization_id)
        logger.debug "Fetching access token for csp organization #{csp_organization_id}"
        api_client = ::Tenant::Clients::CspApiClient::new
        am = api_client.am

        authorization_header = create_authentication_header
        opts = set_oauth_parameters(csp_organization_id)

        authentication_api = ::CspAm::AuthenticationApi::new am

        response = nil
        wf_time(WAVEFRONT_CSP_API_TIME_TAKEN_METRIC, tags: {:name => "get_token"}) do
          response = authentication_api.get_token_for_auth_grant_type_using_post_with_http_info(authorization_header, DEFAULT_GRANT_TYPE, opts)
        end

        wavefront.counter(WAVEFRONT_CSP_API_HIT_COUNT_METRIC, 1, name: 'get_token')

        logger.debug "Fetched access token for csp organization #{csp_organization_id}"
        return response[0].access_token
      end

      private

      def set_oauth_parameters(csp_organization_id)
        opts = {}

        opts[:'org_id'] = csp_organization_id
        opts[:'username'] = settings.csp_account_username
        opts[:'password'] = settings.csp_account_password

        return opts
      end

      def create_authentication_header
        oauth_username = settings.csp_oauth_username
        oauth_password = settings.csp_oauth_password

        return "Basic " + Base64.strict_encode64(oauth_username + ":" + oauth_password)
      end
    end
  end
end