require 'import'
require 'csp-am'
require 'tenant/clients/csp_base_client'
require 'cht-lib-fabric/helpers/wavefront'

module Tenant
  module Clients
    class CspUserClient < CspBaseClient
      include Import['logger', 'settings', :wavefront], ::Tenant::Clients
      include ::Platform::Helpers::Wavefront

      # This method is used to fetch list of csp organizations for csp.local account.
      # This will be used to check if an organization already exists for a tenant and will be used to avoid creating duplicate csp organization.
      def get_csp_organizations_for_a_user(user)
        user_api = get_user_api(settings.csp_ropo_org)
        logger.info "Going to fetch csp organizations for user #{user}"

        response = nil
        wf_time(WAVEFRONT_CSP_API_TIME_TAKEN_METRIC, tags: {:name => "get_user_orgs"}) do
          response = user_api.get_user_orgs_using_get1_with_http_info(user)
        end

        wavefront.counter(WAVEFRONT_CSP_API_HIT_COUNT_METRIC, 1, name: 'get_user_orgs')

        logger.info "Fetched csp organizations for user  #{user}"
        return response[0]
      end

      private

      def get_user_api(csp_organization_id)
        access_token = self.auth_client.fetch_access_token_using_oauth(csp_organization_id)
        am = self.api_client.am(access_token)
        return ::CspAm::UserApi::new am
      end

    end
  end
end