require 'import'
require 'tenant/consumers/application_consumer'

module Tenant
  module Consumers
    class CspOnboardingMessageConsumer < ApplicationConsumer
      include Import['logger', 'tasks.workflow', 'settings', 'handlers.rollbar_handler','handlers.onboard_handler']

      def consume
        logger.info "Received CSP onboarding message = #{params}"

        tenant_id = params['id']

        if ActiveRecord::Type::Boolean.new.cast(settings.csp_enabled)
          begin
            onboard_handler.onboard(params, workflow)
          rescue => ex
            logger.error "Error occurred while onboarding tenant id #{tenant_id} to csp. Error: #{([ex.message]+ex.backtrace).join($/)}"
            rollbar_handler.handle(ex, tenant_id)
          end
        else
          logger.info "CSP onboarding workflow is not enabled. Exiting..."
        end
      end
    end
  end
end