# frozen_string_literal: true

require 'graphql'
require 'tenant/actions'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/helpers/graphql'
require 'container' # or require 'import'
require 'cht-lib-fabric/helpers/graphql/metric_tracing'

GRAPHQL_RESOLVERS = {
  'resolve_type' => lambda { |_type, obj, _ctx|
    ::Tenant::Schema.types[obj.class.name.demodulize]
  },
  "ID" => {
    "coerce_input" => ::Platform::Helpers::GraphQL::ID::CoerceInput.new(services: ["tenant"]),
    # The cht-lib-fabric platform helper actively blocks any response
    # CRN with a customer ID different from the requesting one, but
    # this is common for responses about MSP-managed tenants
    "coerce_result" => ->(crn, _ctx) { crn.to_s }
    # "coerce_result" => ::Platform::Helpers::GraphQL::ID::CoerceResult.new
  },
  "Query" => {
    "node" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::Tenant::Actions::Node, :node
    ),
    "shardAssignment" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::Tenant::Actions::ShardAssignment, :shard_assignment
    ),
    "_service" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::Tenant::Actions::SDLQuery, :service
    ),
    "privacyNotice" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::Tenant::Actions::PrivacyNotice, :privacy_notice
    )
  }
}.freeze

module Tenant
  Schema = GraphQL::Schema.from_definition(
    "app/tenant/graphql/schema.graphql",
    default_resolve: GRAPHQL_RESOLVERS,
    using: {
      ::Platform::Helpers::GraphQL::MetricTracing => {
        client: Application[:wavefront]
      }
    }
  )
end
