require 'import'
require 'tenant/errors/tenant_service_error'


module Tenant
    module Handlers
      class OnboardHandler
        include Import['logger']

        VALID_ONBOARDING_ACTION_TYPES = ["create", "csp-back-fill"]

        #
        # Performs main onboarding logic
        # @param params A hash of input values for the onboard handler
        # @param workflow An instance of a CSPOnboardingWorkflow object
        #
        def onboard(params, workflow)

          tenant_id = params['id']
          tenant_name = params['name']
          action_type = params['action']
          # This will be nil coming from Classic but should
          # have a value when coming from Customer Management
          csp_organization_id = params['csp_organization_id']


          if tenant_id.nil?
            raise ::Tenant::Errors::TenantServiceError.new(nil, "Invalid csp onboarding message. Tenant ID is not present.")
          end

          if tenant_name.nil? or tenant_name.length() == 0
            raise ::Tenant::Errors::TenantServiceError.new(tenant_id, "Invalid csp onboarding message. Tenant name is not present.")
          end

          if !VALID_ONBOARDING_ACTION_TYPES.include? action_type
            raise ::Tenant::Errors::TenantServiceError.new(tenant_id, "Invalid csp onboarding message. Action type is not valid.")
          end

          # If we don't have a CSP organization ID initiate an onboarding flow. For 
          # tenants not being provisioned through Customer Managment service this will be nil initially
          # until the onboarding flow succeeds
          if csp_organization_id.nil?
            workflow.csp_onboarding(tenant_id, tenant_name, nil, nil, nil, true, action_type)
          else
            logger.warn("Not initiating CSP onboarding flow for customer [#{tenant_id}] because it appears to already have a CSP organization attached to it [#{csp_organization_id}]")
          end
            
        end
      end
    end
end