require 'csp-am'
require 'csp-slc'
require 'import'
require 'json'
require 'ostruct'
require 'tenant/errors/tenant_service_error'

module Tenant
  module Handlers
    class RollbarHandler
      include Import['alert', :wavefront]

      def handle(ex, tenant_id = nil, csp_organization_id = nil)
        if ex.nil?
          return
        elsif ex.is_a?(::Tenant::Errors::TenantServiceError)
          alert.exception(
              ex,
              tenant_id: ex.tenant_id,
              csp_organization_id: ex.csp_organization_id
          )
        elsif ex.is_a?(::CspAm::ApiError) or ex.is_a?(::CspSlc::ApiError)
          error_body_json = ex.response_body
          error_body = JSON.parse(error_body_json, object_class: OpenStruct)

          alert.exception(
              ex,
              tenant_id: tenant_id,
              csp_organization_id: csp_organization_id,
              status_code: ex.code,
              csp_error_message: error_body.message,
              csp_request_id: error_body.requestId,
              csp_module_code: error_body.moduleCode
          )
        else
          alert.exception(
              ex,
              tenant_id: tenant_id
          )
        end

        wavefront.counter('com.cloudhealth.svc.tenant.csp-onboarding.failure.count', 1, type: ex.class.name)
      end
    end
  end
end