require 'import'
require 'cht-lib-fabric/dry_types'

module Tenant
  module Producers
    class CspBackfillMessageProducer
      include Import['logger',
                  :settings,
                  'kafka.producers'
              ]

      TOPIC = "com.cloudhealthtech.svc.tenant.change"

      def push(tenant_id, tenant_attributes, action)
        tenant_attributes['action'] = action
        tenant_attributes['crn'] = "crn:#{tenant_id}:tenant/#{tenant_id}"

        topic = if settings.kafka_topic_prefix.blank?
        then TOPIC
                else "#{settings.kafka_topic_prefix}.#{TOPIC}"
                end

        producers.with do |producer|
          producer.produce(tenant_attributes.to_json,
                           key: tenant_id,
                           topic: topic)
          begin
            producer.deliver_messages
            logger.info "Sent kafka message to trigger csp onboarding workflow for tenant id #{tenant_id}"
          rescue ::Kafka::DeliveryFailed
            producer.clear_buffer
            logger.info "Failed to send kafka message to trigger csp onboarding workflow for tenant id #{tenant_id}"
            raise
          end
        end
      end
    end
  end
end