require 'import'
require 'tenant/producers/csp_backfill_message_producer'

module Tenant
  module Tasks
    class CspBackFilling
      include Import['logger', 'stores.tenant_repository', 'handlers.rollbar_handler']
      ACTION_TYPE = "csp-back-fill"
      DELIMITER = " "

      attr_accessor :producer

      def trigger_csp_workflow_for_existing_tenants(tenant_ids_string)
        if tenant_ids_string.nil? or tenant_ids_string.length() == 0
          logger.info "There are no tenant IDs provided to trigger csp workflow"
          return
        end

        tenant_ids = tenant_ids_string.split(DELIMITER)

        @producer = ::Tenant::Producers::CspBackfillMessageProducer.new

        tenant_ids.each do |tenant_id|

          begin
            tenant_attributes = tenant_repository.fetch_tenant_details(tenant_id)
            @producer.push(tenant_id, tenant_attributes, ACTION_TYPE)
          rescue => ex
            logger.error "Error occurred while triggering csp onboarding workflow for tenant id #{tenant_id}. Error: #{([ex.message]+ex.backtrace).join($/)}"
            rollbar_handler.handle(ex, tenant_id)
          end
        end
      end
    end
  end
end