require 'import'
require 'ostruct'
require 'json'

module Tenant
   module Tasks
      class ResetCspWorkflow
         include Import['logger', 'settings', 'stores.csp_onboarding_status_repo', 'handlers.rollbar_handler', 'stores.tenant_repository']
         DELIMITER = " "

         def reset_csp_workflow_for_existing_tenants(tenant_ids_string)
            if tenant_ids_string.nil? or tenant_ids_string.length() == 0
                logger.info "There are no tenant IDs provided to reset csp workflow"
                return
            end

            begin

                logger.info("Resetting workflows for tenant ids #{tenant_ids_string}")

                tenant_ids = tenant_ids_string.split(DELIMITER).map(&:to_i)

                logger.info("Munged tenant_ids #{tenant_ids}")
        
                tenant_ids.each do |tenant_id|
                    logger.info("Resetting workflow for tenant #{tenant_id}")

                    # Get the workflow from DynamoDB
                    response = csp_onboarding_status_repo.fetch_onboarding_status_for_tenant(tenant_id)

                    # Just one item ass we're looping per tenant
                    results = [response.item]

                    # Did not find any workflows for anything
                    raise "No workflow found for tenants #{tenant_id}" unless results.length > 0

                    # Make sure we only pick up one item per tenant
                    raise "There should only be one item per tenant workflow returned" if results.length > 1

                    logger.info("Onboarding status found for #{tenant_id} - #{results}")

                    # Reset workflow by deleting item
                    results.each do |item|
                        workflow_detail = JSON.parse(item.to_json, object_class: OpenStruct)
                        logger.info("WorkFlow detail #{workflow_detail}")
                        # Do the actual reset
                        if workflow_detail.currentStatus.eql?("new") && workflow_detail.currentStatusId.to_i == 1
                            csp_onboarding_status_repo.reset_workflow(workflow_detail.tenantId.to_i)
                        else
                            logger.info("Not resetting workflow for #{tenant_id} as it's not in new state")
                        end
                       
                        logger.info("Workflow reset for #{tenant_id}")
                    end
                end
            rescue
                logger.error "Unable to reset workflows for  #{tenant_ids}"
                raise                 
            end

         end
      end
    end
end